@@ -333,14 +333,10 @@ c       * process for the events
       write(0, *) 
      *  ' *  In your own normal job, you have to disable   * '
       write(0, *) 
-     *  " *    'taking Trace info' by setting Trace f      * "
+     *  " *    'taking Trace info' by setting 'Trace f'    * "
       write(0, *) 
      *  " *     in 'epicsfile'                             * "
       write(0, *)
-     *  " *    You should copy Template to make your       * "
-      write(0, *) 
-     *  " *  applicatons rather than FirstKiss             * "
-      write(0, *)
      *  ' *               G o o d  L u c k  !              * '
       write(0, *) 
      *  ' ************************************************** '
